package com.usky.demo.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.exception.BusinessException;
import com.usky.common.core.util.BeanMapperUtils;
import com.usky.common.core.util.FileUtils;
import com.usky.common.core.util.GlobalUtils;
import com.usky.demo.RemoteTsdbProxyService;
import com.usky.demo.domain.*;
import com.usky.demo.service.QueryInfluxdbDataService;
import com.usky.demo.service.SysUserService;
import com.usky.system.RemoteUserService;
import com.usky.system.domain.SysUserVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@RestController
public class DataTsdbProxyControllerApi implements RemoteTsdbProxyService {

    @Autowired
    private QueryInfluxdbDataService queryInfluxdbDataService;

    /**
     * 获取设备实时数据(对内)
     * @param requestVO
     * @return
     */
    @Override
    public List<LastInnerResultVO> last(LastInnerQueryVO requestVO){
        return queryInfluxdbDataService.last(requestVO);
    }

    /**
     * 查询influxdb所有表实时数据
     * @return
     */
    @Override
    public ApiResult<List<Map<String, Object>>> getAllDeviceRealTime(){
        return ApiResult.success(queryInfluxdbDataService.getAllDeviceRealTime());
    }

    /**
     * 单个设备实时数据查询
     * @param deviceUUId
     * @return
     */
    @Override
    public LastResultVO queryLastDeviceData(String deviceUUId){
        return queryInfluxdbDataService.queryLastDeviceData(deviceUUId);
    }

    /**
     * 批量设备实时数据查询
     * @param requestVO
     * @return
     */
    @Override
    public List<LastResultVO> queryLastDeviceData(LastRequestVO requestVO){
        return queryInfluxdbDataService.queryLastDeviceData(requestVO);
    }

    /**
     * 单个设备历史数据查询
     * @param deviceUUId
     * @param startTime
     * @param endTime
     * @return
     */
    @Override
    public HistoryResultVO queryHistoryDeviceData(String deviceUUId,
                                                             String startTime,
                                                             String endTime){
        return queryInfluxdbDataService.queryHistoryDeviceData(deviceUUId,startTime,endTime);
    }

    /**
     * 批量设备历史数据查询
     * @param requestVO
     * @return
     */
    @Override
    public List<HistoryResultVO> queryHistoryDeviceData(HistoryRequestVO requestVO){
        return queryInfluxdbDataService.queryHistoryDeviceData(requestVO);
    }
}
